package com.ruoyi.project.zjsgfa.mapper;

import java.util.List;
import com.ruoyi.project.zjsgfa.domain.SjGztz;

/**
 * 设计信息-构造特征Mapper接口
 * 
 * @author ruoyi
 * @date 2025-07-22
 */
public interface SjGztzMapper 
{
    /**
     * 查询设计信息-构造特征
     * 
     * @param id 设计信息-构造特征主键
     * @return 设计信息-构造特征
     */
    public SjGztz selectSjGztzById(Long id);

    /**
     * 查询设计信息-构造特征列表
     * 
     * @param sjGztz 设计信息-构造特征
     * @return 设计信息-构造特征集合
     */
    public List<SjGztz> selectSjGztzList(SjGztz sjGztz);

    /**
     * 新增设计信息-构造特征
     * 
     * @param sjGztz 设计信息-构造特征
     * @return 结果
     */
    public int insertSjGztz(SjGztz sjGztz);

    /**
     * 修改设计信息-构造特征
     * 
     * @param sjGztz 设计信息-构造特征
     * @return 结果
     */
    public int updateSjGztz(SjGztz sjGztz);

    /**
     * 删除设计信息-构造特征
     * 
     * @param id 设计信息-构造特征主键
     * @return 结果
     */
    public int deleteSjGztzById(Long id);

    /**
     * 批量删除设计信息-构造特征
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSjGztzByIds(Long[] ids);

    int deleteSjGztzByJh(String jh);

    int insertSjGztzBatch(List<SjGztz> sjGztzList);


}
